<?php
$translations = array(
	'General_Locale' => 'en_EN.UTF-8',
	'General_TranslatorName' => '-',
	'General_TranslatorEmail' => 'hello@piwik.org',
	'General_EnglishLanguageName' => 'English',
	'General_OriginalLanguageName' => 'English',
	'General_HelloUser'	=> 'Hello, %s!',
	'General_OpenSourceWebAnalytics' => 'Open Source Web Analytics',
	'General_Dashboard' => 'Dashboard',
	'General_MultiSitesSummary' => 'All Websites',
	'General_API' => 'API',
	'General_Widgets' => 'Widgets',
	'General_Settings'	=> 'Settings',
	'General_GiveUsYourFeedback' => 'Give us Feedback!',
	'General_Unknown' => 'Unknown',
	'General_Required' => '%s required',
	'General_Error' => 'Error',
	'General_Warning' => 'Warning',
	'General_BackToHomepage' => 'Back to Piwik homepage',
	'General_Yes' => 'Yes',
	'General_No' => 'No',
	'General_Delete' => 'Delete',
	'General_Edit' => 'Edit',
	'General_Ok' => 'Ok',
	'General_Close' => 'Close',
	'General_Logout' => 'Sign out',
	'General_Done' => 'Done',
	'General_LoadingData' => 'Loading data...',
	'General_Loading' => 'Loading...',
	'General_ErrorRequest' => 'Oops&hellip; problem during the request, please try again.',
	'General_Next' => 'Next',
	'General_Previous' => 'Previous',
	'General_Search' => 'Search',
	'General_Others' => 'Others',
	'General_Table' => 'Table',
	'General_Piechart' => 'Piechart',
	'General_TagCloud' => 'Tag Cloud',
	'General_VBarGraph' => 'Vertical bar graph',
	'General_Export' => 'Export',
	'General_ExportAsImage_js' => 'Export as Image',
	'General_SaveImageOnYourComputer_js' => 'To save the image on your computer, right click on the image and select "Save Image As..."',
	'General_Refresh' => 'Refresh the page',
	'General_Visitors' => 'Visitors',
	'General_ColumnNbUniqVisitors' => 'Unique visitors',
	'General_ColumnNbVisits' => 'Visits',
	'General_ColumnNbActions' => 'Actions',
	'General_ColumnMaxActions' => 'Maximum actions in one visit',
	'General_ColumnSumVisitLength' => 'Total time spent by visitors (in seconds)',
	'General_ColumnLabel' => 'Label',
	'General_ColumnActionsPerVisit' => 'Actions per Visit',
	'General_ColumnAvgTimeOnSite' => 'Avg. Time on Website',
	'General_ColumnBounceRate' => 'Bounce Rate',
	'General_ColumnPageviews' => 'Pageviews',
	'General_ColumnUniquePageviews' => 'Unique Pageviews',
	'General_ColumnValuePerVisit' => 'Value per Visit',
	'General_ColumnVisitsWithConversions' => 'Visits with Conversions',
	'General_Save' => 'Save',
	'General_Website' => 'Website',
	'General_RequiresFlash' => 'Displaying Graphs in Piwik requires Flash',
	'General_GraphHelp' => 'More information about displaying graphs in Piwik.',
	'General_NoDataForGraph' => 'No data for this graph.',
	'General_NoDataForTagCloud' => 'No data for this tag cloud.',
	'General_DisplayNormalTable' => 'Display normal table',
	'General_DisplayMoreData' => 'Display more data',
	'General_PiwikIsACollaborativeProjectYouCanContribute' => '%s Piwik %s is a collaborative project. %s If you like Piwik, you can help! Check out %s How to contribute to Piwik?%s ',
	'General_YouAreCurrentlyViewingDemoOfPiwik' => 'You are currently viewing the demo of %s; %sdownload%s the full version! Check out %s',
	'General_PiwikXIsAvailablePleaseUpdateNow' => 'Piwik %s is available. %s Please update now!%s (see %s changes%s).',
	'General_BackToPiwik' => 'Back to Piwik',
	'General_ShortMonth_1' => 'Jan',
	'General_ShortMonth_2' => 'Feb',
	'General_ShortMonth_3' => 'Mar',
	'General_ShortMonth_4' => 'Apr',
	'General_ShortMonth_5' => 'May',
	'General_ShortMonth_6' => 'Jun',
	'General_ShortMonth_7' => 'Jul',
	'General_ShortMonth_8' => 'Aug',
	'General_ShortMonth_9' => 'Sep',
	'General_ShortMonth_10' => 'Oct',
	'General_ShortMonth_11' => 'Nov',
	'General_ShortMonth_12' => 'Dec',
	'General_LongMonth_1' => 'January',
	'General_LongMonth_2' => 'February',
	'General_LongMonth_3' => 'March',
	'General_LongMonth_4' => 'April',
	'General_LongMonth_5' => 'May',
	'General_LongMonth_6' => 'June',
	'General_LongMonth_7' => 'July',
	'General_LongMonth_8' => 'August',
	'General_LongMonth_9' => 'September',
	'General_LongMonth_10' => 'October',
	'General_LongMonth_11' => 'November',
	'General_LongMonth_12' => 'December',
	'General_ShortDay_1' => 'Mon',
	'General_ShortDay_2' => 'Tue',
	'General_ShortDay_3' => 'Wed',
	'General_ShortDay_4' => 'Thu',
	'General_ShortDay_5' => 'Fri',
	'General_ShortDay_6' => 'Sat',
	'General_ShortDay_7' => 'Sun',
	'General_LongDay_1' => 'Monday',
	'General_LongDay_2' => 'Tuesday',
	'General_LongDay_3' => 'Wednesday',
	'General_LongDay_4' => 'Thursday',
	'General_LongDay_5' => 'Friday',
	'General_LongDay_6' => 'Saturday',
	'General_LongDay_7' => 'Sunday',
	'General_ExceptionDatabaseVersion' => 'Your %s version is %s but Piwik requires at least %s.',
	'CorePluginsAdmin_Plugins' => 'Plugins',
	'CorePluginsAdmin_PluginsManagement' => 'Plugins Management',
	'CorePluginsAdmin_MainDescription' => 'Plugins extend and expand the functionality of Piwik. Once a plugin is installed, you may activate it or deactivate it here.',
	'CorePluginsAdmin_Plugin' => 'Plugin',
	'CorePluginsAdmin_Version' => 'Version',
	'CorePluginsAdmin_Description' => 'Description',
	'CorePluginsAdmin_Status' => 'Status',
	'CorePluginsAdmin_Action' => 'Action',
	'CorePluginsAdmin_PluginHomepage' => 'Plugin Homepage',
	'CorePluginsAdmin_Activated' => 'Activated',
	'CorePluginsAdmin_Active' => 'Active',
	'CorePluginsAdmin_Inactive' => 'Inactive',
	'CorePluginsAdmin_ActivatedHelp' => 'This plugin cannot be deactivated',
	'CorePluginsAdmin_Deactivate' => 'Deactivate',
	'CorePluginsAdmin_Activate' => 'Activate',
	'CorePluginsAdmin_MenuPlugins' => 'Plugins',
	'API_QuickDocumentation' => '<h2>API quick documentation</h2><p>If you don\'t have data for today you can first <a href=\'misc/generateVisits.php\' target=_blank>generate some data</a> using the Visits Generator script.</p><p>You can try the different formats available for every method. It is very easy to extract any data you want from Piwik!</p><p><b>For more information have a look at the <a href=\'http://dev.piwik.org/trac/wiki/API\'>official API Documentation</a> or the <a href=\'http://dev.piwik.org/trac/wiki/API/Reference\'>API Reference</a>.</b></P><h2>User authentication</h2><p>If you want to <b>request the data in your scripts, in a crontab, etc. </b> you need to add the parameter <code><u>&token_auth=%s</u></code> to the API calls URLs that require authentication.</p><p>This token_auth is as secret as your login and password, <b>do not share it!</p>',
	'API_LoadedAPIs' => 'Loaded successfully %s APIs',
	'CoreHome_NoPrivileges' => 'You are logged in as \'%s\' but it seems you don\'t have any permission set in Piwik.<br />Ask your Piwik administrator to give you \'view\' access to a website.',
	'CoreHome_JavascriptDisabled' => 'JavaScript must be enabled in order for you to use Piwik in standard view.<br />However, it seems JavaScript is either disabled or not supported by your browser.<br />To use standard view, enable JavaScript by changing your browser options, then %stry again%s.<br />',
	'CoreHome_TableNoData' => 'No data for this table.',
	'CoreHome_CategoryNoData' => 'No data in this category. Try to "Include all population".',
	'CoreHome_ShowJSCode' => 'Show the JavaScript code to insert',
	'CoreHome_IncludeAllPopulation_js' => 'Include all population',
	'CoreHome_ExcludeLowPopulation_js' => 'Exclude low population',
	'CoreHome_PageOf_js' => '%s of %s',
	'CoreHome_Loading_js' => 'Loading...',
	'CoreHome_DayFormat' => '%longDay% %day% %longMonth% %longYear%',
	'CoreHome_PeriodDay' => 'Day',
	'CoreHome_PeriodWeek' => 'Week',
	'CoreHome_PeriodMonth' => 'Month',
	'CoreHome_PeriodYear' => 'Year',
	'CoreHome_PeriodDays' => 'days',
	'CoreHome_PeriodWeeks' => 'weeks',
	'CoreHome_PeriodMonths' => 'months',
	'CoreHome_PeriodYears' => 'years',
	'CoreHome_DaySu_js' => 'Su',
	'CoreHome_DayMo_js' => 'Mo',
	'CoreHome_DayTu_js' => 'Tu',
	'CoreHome_DayWe_js' => 'We',
	'CoreHome_DayTh_js' => 'Th',
	'CoreHome_DayFr_js' => 'Fr',
	'CoreHome_DaySa_js' => 'Sa',
	'CoreHome_ShortDay_1_js' => 'Sun',
	'CoreHome_ShortDay_2_js' => 'Mon',
	'CoreHome_ShortDay_3_js' => 'Tue',
	'CoreHome_ShortDay_4_js' => 'Wed',
	'CoreHome_ShortDay_5_js' => 'Thu',
	'CoreHome_ShortDay_6_js' => 'Fri',
	'CoreHome_ShortDay_7_js' => 'Sat',
	'CoreHome_LongDay_1_js' => 'Sunday',
	'CoreHome_LongDay_2_js' => 'Monday',
	'CoreHome_LongDay_3_js' => 'Tuesday',
	'CoreHome_LongDay_4_js' => 'Wednesday',
	'CoreHome_LongDay_5_js' => 'Thursday',
	'CoreHome_LongDay_6_js' => 'Friday',
	'CoreHome_LongDay_7_js' => 'Saturday',
	'CoreHome_ShortMonth_1_js' => 'Jan',
	'CoreHome_ShortMonth_2_js' => 'Feb',
	'CoreHome_ShortMonth_3_js' => 'Mar',
	'CoreHome_ShortMonth_4_js' => 'Apr',
	'CoreHome_ShortMonth_5_js' => 'May',
	'CoreHome_ShortMonth_6_js' => 'Jun',
	'CoreHome_ShortMonth_7_js' => 'Jul',
	'CoreHome_ShortMonth_8_js' => 'Aug',
	'CoreHome_ShortMonth_9_js' => 'Sep',
	'CoreHome_ShortMonth_10_js' => 'Oct',
	'CoreHome_ShortMonth_11_js' => 'Nov',
	'CoreHome_ShortMonth_12_js' => 'Dec',
	'CoreHome_MonthJanuary_js' => 'January',
	'CoreHome_MonthFebruary_js' => 'February',
	'CoreHome_MonthMarch_js' => 'March',
	'CoreHome_MonthApril_js' => 'April',
	'CoreHome_MonthMay_js' => 'May',
	'CoreHome_MonthJune_js' => 'June',
	'CoreHome_MonthJuly_js' => 'July',
	'CoreHome_MonthAugust_js' => 'August',
	'CoreHome_MonthSeptember_js' => 'September',
	'CoreHome_MonthOctober_js' => 'October',
	'CoreHome_MonthNovember_js' => 'November',
	'CoreHome_MonthDecember_js' => 'December',
	'CoreUpdater_UpdateTitle' => 'Update',
	'CoreUpdater_DatabaseUpgradeRequired' => 'Database Upgrade Required',
	'CoreUpdater_YourDatabaseIsOutOfDate' => 'Your Piwik database is out-of-date, and must be upgraded before you can continue.',
	'CoreUpdater_PiwikWillBeUpgradedFromVersionXToVersionY' => 'Piwik database will be upgraded from version %s to the new version %s.',
	'CoreUpdater_TheFollowingPluginsWillBeUpgradedX' => 'The following plugins will be updated: %s.',
	'CoreUpdater_TheUpgradeProcessMayFailExecuteCommand' => 'If you have a large Piwik database, updates might take too long to run in the browser. In this situation, you can execute the updates from your command line: %s',
	'CoreUpdater_TheUpgradeProcessMayTakeAWhilePleaseBePatient' => 'The database upgrade process may take a while, so please be patient.',
	'CoreUpdater_UpgradePiwik' => 'Upgrade Piwik',
	'CoreUpdater_ErrorDIYHelp' => 'If you are an advanced user and encounter an error in the database upgrade:',
	'CoreUpdater_ErrorDIYHelp_1' => 'identify and correct the source of the problem (e.g., memory_limit or max_execution_time)',
	'CoreUpdater_ErrorDIYHelp_2' => 'execute the remaining queries in the update that failed',
	'CoreUpdater_ErrorDIYHelp_3' => 'manually update the `option` table in your Piwik database, setting the value of version_core to the version of the failed update',
	'CoreUpdater_ErrorDIYHelp_4' => 're-run the updater (through the browser or command-line) to continue with the remaining updates',
	'CoreUpdater_ErrorDIYHelp_5' => 'report the problem (and solution) so that Piwik can be improved',
	'CoreUpdater_HelpMessageContent' => 'Check the %s Piwik FAQ %s which explains most common errors during update. %s Ask your system administrator - they may be able to help you with the error which is most likely related to your server or MySQL setup.',
	'CoreUpdater_CriticalErrorDuringTheUpgradeProcess' => 'Critical Error during the update process:',
	'CoreUpdater_HelpMessageIntroductionWhenError' => 'The above is the core error message. It should help explain the cause, but if you require further help please:',
	'CoreUpdater_HelpMessageIntroductionWhenWarning' => 'The update completed successfuly, however there were issues during the process. Please read the above descriptions for details. For further help:',
	'CoreUpdater_UpgradeComplete' => 'Upgrade complete!',
	'CoreUpdater_WarningMessages' => 'Warning messages:',
	'CoreUpdater_ErrorDuringPluginsUpdates' => 'Error during plugin updates:',
	'CoreUpdater_WeAutomaticallyDeactivatedTheFollowingPlugins' => 'We automatically deactivated the following plugins: %s',
	'CoreUpdater_PiwikHasBeenSuccessfullyUpgraded' => 'Piwik has been successfully updated!',
	'CoreUpdater_ContinueToPiwik' => 'Continue to Piwik',
	'CoreUpdater_UpdateAutomatically' => 'Update Automatically',
	'CoreUpdater_ThereIsNewVersionAvailableForUpdate' => 'There is a new version of Piwik available for update',
	'CoreUpdater_YouCanUpgradeAutomaticallyOrDownloadPackage' => 'You can update to version %s automatically or download the package and install it manually:',
	'CoreUpdater_DownloadX' => 'Download %s',
	'CoreUpdater_UpdateHasBeenCancelledExplanation' => 'Piwik One Click Update has been cancelled. If you can\'t fix the above error message, it is recommended that you manually update Piwik. %s Please check out the %sUpdate documentation%s to get started!',
	'CoreUpdater_DownloadingUpdateFromX' => 'Downloading update from %s',
	'CoreUpdater_UnpackingTheUpdate' => 'Unpacking the update',
	'CoreUpdater_VerifyingUnpackedFiles' => 'Verifying the unpacked files',
	'CoreUpdater_CreatingBackupOfConfigurationFile' => 'Creating a backup of the configuration file in %s',
	'CoreUpdater_InstallingTheLatestVersion' => 'Installing the latest version',
	'CoreUpdater_PiwikUpdatedSuccessfully' => 'Piwik updated successfully!',
	'CoreUpdater_EmptyDatabaseError' => 'Database %s is empty. You must edit or remove your Piwik configuration file.',
	'CoreUpdater_ExceptionAlreadyLatestVersion' => 'Your Piwik version %s is up to date.',
	'CoreUpdater_ExceptionArchiveIncompatible' => 'Incompatible archive: %s',
	'CoreUpdater_ExceptionArchiveEmpty' => 'Empty archive.',
	'CoreUpdater_ExceptionArchiveIncomplete' => 'Archive is incomplete: some files are missing (eg. %s).',
	'Actions_Actions' => 'Actions',
	'Actions_SubmenuPages' => 'Pages',
	'Actions_SubmenuPageTitles' => 'Page titles',
	'Actions_SubmenuOutlinks' => 'Outlinks',
	'Actions_SubmenuDownloads' => 'Downloads',
	'Actions_ColumnClicks' => 'Clicks',
	'Actions_ColumnUniqueClicks' => 'Unique Clicks',
	'Actions_ColumnDownloads' => 'Downloads',
	'Actions_ColumnUniqueDownloads' => 'Unique Downloads',
	'Actions_ColumnPageName' => 'Page Name',
	'Actions_ColumnPageURL' => 'Page URL',
	'Actions_ColumnClickedURL' => 'Clicked URL',
	'Actions_ColumnDownloadURL' => 'Download URL',
	'Dashboard_Dashboard' => 'Dashboard',
	'Dashboard_AddWidget' => 'Add a widget...',
	'Dashboard_DeleteWidgetConfirm' => 'Are you sure you want to delete this widget from the dashboard?',
	'Dashboard_SelectWidget' => 'Select the widget to add in the dashboard',
	'Dashboard_AddPreviewedWidget_js' => 'Add previewed widget to the dashboard',
	'Dashboard_WidgetPreview_js' => 'Widget preview',
	'Dashboard_Close_js' => 'Close',
	'Dashboard_TitleWidgetInDashboard_js' => 'Widget already in dashboard',
	'Dashboard_TitleClickToAdd_js' => 'Click to add to dashboard',
	'Dashboard_LoadingWidget_js' => 'Loading widget, please wait...',
	'Dashboard_WidgetNotFound_js' => 'Widget not found',
	'Referers_Referers' => 'Referers',
	'Referers_SearchEngines' => 'Search Engines',
	'Referers_Keywords' => 'Keywords',
	'Referers_DirectEntry' => 'Direct Entry',
	'Referers_Websites' => 'Websites',
	'Referers_Campaigns' => 'Campaigns',
	'Referers_MetricsFromRefererTypeGraphLegend' => '%s (from %s)',
	'Referers_Evolution' => 'Evolution over the period',
	'Referers_Type' => 'Referer Type',
	'Referers_ColumnRefererType' => 'Referer Type',
	'Referers_ColumnSearchEngine' => 'Search Engine',
	'Referers_ColumnWebsite' => 'Website',
	'Referers_ColumnWebsitePage' => 'Website Page',
	'Referers_ColumnKeyword' => 'Keyword',
	'Referers_ColumnCampaign' => 'Campaign',
	'Referers_DetailsByRefererType' => 'Details by Referer Type',
	'Referers_TypeDirectEntries' => '%s direct entries',
	'Referers_TypeSearchEngines' => '%s from search engines',
	'Referers_TypeWebsites' => '%s from websites',
	'Referers_TypeCampaigns' => '%s from campaigns',
	'Referers_Distinct' => 'Distinct Referers by Referer Type',
	'Referers_DistinctSearchEngines' => 'distinct search engines',
	'Referers_DistinctKeywords' => 'distinct keywords',
	'Referers_DistinctCampaigns' => 'distinct campaigns',
	'Referers_DistinctWebsites' => 'distinct websites',
	'Referers_UsingNDistinctUrls' => ' (using %2s distinct urls)',
	'Referers_SubmenuEvolution' => 'Evolution',
	'Referers_SubmenuSearchEngines' => 'Search Engines &amp; Keywords',
	'Referers_SubmenuWebsites' => 'Websites',
	'Referers_SubmenuCampaigns' => 'Campaigns',
	'Referers_WidgetKeywords' => 'List of Keywords',
	'Referers_WidgetCampaigns' => 'List of Campaigns',
	'Referers_WidgetExternalWebsites' => 'List of external Websites',
	'Referers_WidgetSearchEngines' => 'Best search engines',
	'Referers_WidgetOverview' => 'Overview',
	'UserSettings_VisitorSettings' => 'Visitor Settings',
	'UserSettings_BrowserFamilies' => 'Browser families',
	'UserSettings_Browsers' => 'Browsers',
	'UserSettings_Plugins' => 'Plugins',
	'UserSettings_Configurations' => 'Configurations',
	'UserSettings_OperatingSystems' => 'Operating systems',
	'UserSettings_Resolutions' => 'Resolutions',
	'UserSettings_WideScreen' => 'Wide Screen',
	'UserSettings_ColumnBrowserFamily' => 'Browser family',
	'UserSettings_ColumnBrowser' => 'Browser',
	'UserSettings_ColumnPlugin' => 'Plugin',
	'UserSettings_ColumnConfiguration' => 'Configuration',
	'UserSettings_ColumnOperatingSystem' => 'Operating system',
	'UserSettings_ColumnResolution' => 'Resolution',
	'UserSettings_ColumnTypeOfScreen' => 'Type of screen',
	'UserSettings_WidgetResolutions' => 'Screen resolutions',
	'UserSettings_WidgetBrowsers' => 'Visitor browsers',
	'UserSettings_WidgetPlugins' => 'List of Plugins',
	'UserSettings_WidgetWidescreen' => 'Normal / Widescreen',
	'UserSettings_WidgetBrowserFamilies' => 'Browsers by family',
	'UserSettings_WidgetOperatingSystems' => 'Operating systems',
	'UserSettings_WidgetGlobalVisitors' => 'Global visitors configuration',
	'UserSettings_SubmenuSettings' => 'Settings',
	'UserCountry_Country' => 'Country',
	'UserCountry_Continent' => 'Continent',
	'UserCountry_DistinctCountries' => '%s distinct countries',
	'UserCountry_SubmenuLocations' => 'Locations',
	'UserCountry_WidgetContinents' => 'Visitor continents',
	'UserCountry_WidgetCountries' => 'Visitor countries',
	'UserCountry_country_ac' => 'Ascension Islands',
	'UserCountry_country_ad' => 'Andorra',
	'UserCountry_country_ae' => 'United Arab Emirates',
	'UserCountry_country_af' => 'Afghanistan',
	'UserCountry_country_ag' => 'Antigua and Barbuda',
	'UserCountry_country_ai' => 'Anguilla',
	'UserCountry_country_al' => 'Albania',
	'UserCountry_country_am' => 'Armenia',
	'UserCountry_country_an' => 'Netherlands Antilles',
	'UserCountry_country_ao' => 'Angola',
	'UserCountry_country_aq' => 'Antarctica',
	'UserCountry_country_ar' => 'Argentina',
	'UserCountry_country_as' => 'American Samoa',
	'UserCountry_country_at' => 'Austria',
	'UserCountry_country_au' => 'Australia',
	'UserCountry_country_aw' => 'Aruba',
	'UserCountry_country_ax' => 'Aland Islands',
	'UserCountry_country_az' => 'Azerbaijan',
	'UserCountry_country_ba' => 'Bosnia and Herzegovina',
	'UserCountry_country_bb' => 'Barbados',
	'UserCountry_country_bd' => 'Bangladesh',
	'UserCountry_country_be' => 'Belgium',
	'UserCountry_country_bf' => 'Burkina Faso',
	'UserCountry_country_bg' => 'Bulgaria',
	'UserCountry_country_bh' => 'Bahrain',
	'UserCountry_country_bi' => 'Burundi',
	'UserCountry_country_bj' => 'Benin',
	'UserCountry_country_bl' => 'Saint Barthelemy',
	'UserCountry_country_bm' => 'Bermuda',
	'UserCountry_country_bn' => 'Bruneo',
	'UserCountry_country_bo' => 'Bolivia',
	'UserCountry_country_br' => 'Brazil',
	'UserCountry_country_bs' => 'Bahamas',
	'UserCountry_country_bt' => 'Bhutan',
	'UserCountry_country_bu' => 'Burma',
	'UserCountry_country_bv' => 'Bouvet Island',
	'UserCountry_country_bw' => 'Botswana',
	'UserCountry_country_by' => 'Belarus',
	'UserCountry_country_bz' => 'Belize',
	'UserCountry_country_ca' => 'Canada',
	'UserCountry_country_cc' => 'Cocos (Keeling) Islands',
	'UserCountry_country_cd' => 'Congo, The Democratic Republic of the',
	'UserCountry_country_cf' => 'Central African Republic',
	'UserCountry_country_cg' => 'Congo',
	'UserCountry_country_ch' => 'Switzerland',
	'UserCountry_country_ci' => 'Cote D\'Ivoire',
	'UserCountry_country_ck' => 'Cook Islands',
	'UserCountry_country_cl' => 'Chile',
	'UserCountry_country_cm' => 'Cameroon',
	'UserCountry_country_cn' => 'China',
	'UserCountry_country_co' => 'Colombia',
	'UserCountry_country_cp' => 'Clipperton Island',
	'UserCountry_country_cr' => 'Costa Rica',
	'UserCountry_country_cs' => 'Serbia Montenegro',
	'UserCountry_country_cu' => 'Cuba',
	'UserCountry_country_cv' => 'Cape Verde',
	'UserCountry_country_cx' => 'Christmas Island',
	'UserCountry_country_cy' => 'Cyprus',
	'UserCountry_country_cz' => 'Czech Republic',
	'UserCountry_country_de' => 'Germany',
	'UserCountry_country_dg' => 'Diego Garcia',
	'UserCountry_country_dj' => 'Djibouti',
	'UserCountry_country_dk' => 'Denmark',
	'UserCountry_country_dm' => 'Dominica',
	'UserCountry_country_do' => 'Dominican Republic',
	'UserCountry_country_dz' => 'Algeria',
	'UserCountry_country_ea' => 'Ceuta, Melilla',
	'UserCountry_country_ec' => 'Ecuador',
	'UserCountry_country_ee' => 'Estonia',
	'UserCountry_country_eg' => 'Egypt',
	'UserCountry_country_eh' => 'Western Sahara',
	'UserCountry_country_er' => 'Eritrea',
	'UserCountry_country_es' => 'Spain',
	'UserCountry_country_et' => 'Ethiopia',
	'UserCountry_country_eu' => 'European Union',
	'UserCountry_country_fi' => 'Finland',
	'UserCountry_country_fj' => 'Fiji',
	'UserCountry_country_fk' => 'Falkland Islands (Malvinas)',
	'UserCountry_country_fm' => 'Micronesia, Federated States of',
	'UserCountry_country_fo' => 'Faroe Islands',
	'UserCountry_country_fr' => 'France',
	'UserCountry_country_fx' => 'France, Metropolitan',
	'UserCountry_country_ga' => 'Gabon',
	'UserCountry_country_gb' => 'Great Britain',
	'UserCountry_country_gd' => 'Grenada',
	'UserCountry_country_ge' => 'Georgia',
	'UserCountry_country_gf' => 'French Guyana',
	'UserCountry_country_gg' => 'Guernsey',
	'UserCountry_country_gh' => 'Ghana',
	'UserCountry_country_gi' => 'Gibraltar',
	'UserCountry_country_gl' => 'Greenland',
	'UserCountry_country_gm' => 'Gambia',
	'UserCountry_country_gn' => 'Guinea',
	'UserCountry_country_gp' => 'Guadeloupe',
	'UserCountry_country_gq' => 'Equatorial Guinea',
	'UserCountry_country_gr' => 'Greece',
	'UserCountry_country_gs' => 'South Georgia and the South Sandwich Islands',
	'UserCountry_country_gt' => 'Guatemala',
	'UserCountry_country_gu' => 'Guam',
	'UserCountry_country_gw' => 'Guinea-Bissau',
	'UserCountry_country_gy' => 'Guyana',
	'UserCountry_country_hk' => 'Hong Kong',
	'UserCountry_country_hm' => 'Heard Island and McDonald Islands',
	'UserCountry_country_hn' => 'Honduras',
	'UserCountry_country_hr' => 'Croatia',
	'UserCountry_country_ht' => 'Haiti',
	'UserCountry_country_hu' => 'Hungary',
	'UserCountry_country_ic' => 'Canary Islands',
	'UserCountry_country_id' => 'Indonesia',
	'UserCountry_country_ie' => 'Ireland',
	'UserCountry_country_il' => 'Israel',
	'UserCountry_country_im' => 'Man Island',
	'UserCountry_country_in' => 'India',
	'UserCountry_country_io' => 'British Indian Ocean Territory',
	'UserCountry_country_iq' => 'Iraq',
	'UserCountry_country_ir' => 'Iran, Islamic Republic of',
	'UserCountry_country_is' => 'Iceland',
	'UserCountry_country_it' => 'Italy',
	'UserCountry_country_je' => 'Jersey',
	'UserCountry_country_jm' => 'Jamaica',
	'UserCountry_country_jo' => 'Jordan',
	'UserCountry_country_jp' => 'Japan',
	'UserCountry_country_ke' => 'Kenya',
	'UserCountry_country_kg' => 'Kyrgyzstan',
	'UserCountry_country_kh' => 'Cambodia',
	'UserCountry_country_ki' => 'Kiribati',
	'UserCountry_country_km' => 'Comoros',
	'UserCountry_country_kn' => 'Saint Kitts and Nevis',
	'UserCountry_country_kp' => 'Korea, Democratic People\'s Republic of',
	'UserCountry_country_kr' => 'Korea, Republic of',
	'UserCountry_country_kw' => 'Kuwait',
	'UserCountry_country_ky' => 'Cayman Islands',
	'UserCountry_country_kz' => 'Kazakhstan',
	'UserCountry_country_la' => 'Laos',
	'UserCountry_country_lb' => 'Lebanon',
	'UserCountry_country_lc' => 'Saint Lucia',
	'UserCountry_country_li' => 'Liechtenstein',
	'UserCountry_country_lk' => 'Sri Lanka',
	'UserCountry_country_lr' => 'Liberia',
	'UserCountry_country_ls' => 'Lesotho',
	'UserCountry_country_lt' => 'Lithuania',
	'UserCountry_country_lu' => 'Luxembourg',
	'UserCountry_country_lv' => 'Latvia',
	'UserCountry_country_ly' => 'Libya',
	'UserCountry_country_ma' => 'Morocco',
	'UserCountry_country_mc' => 'Monaco',
	'UserCountry_country_md' => 'Moldova, Republic of',
	'UserCountry_country_me' => 'Montenegro',
	'UserCountry_country_mf' => 'Saint Martin',
	'UserCountry_country_mg' => 'Madagascar',
	'UserCountry_country_mh' => 'Marshall Islands',
	'UserCountry_country_mk' => 'Macedonia',
	'UserCountry_country_ml' => 'Mali',
	'UserCountry_country_mm' => 'Myanmar',
	'UserCountry_country_mn' => 'Mongolia',
	'UserCountry_country_mo' => 'Macau',
	'UserCountry_country_mp' => 'Northern Mariana Islands',
	'UserCountry_country_mq' => 'Martinique',
	'UserCountry_country_mr' => 'Mauritania',
	'UserCountry_country_ms' => 'Montserrat',
	'UserCountry_country_mt' => 'Malta',
	'UserCountry_country_mu' => 'Mauritius',
	'UserCountry_country_mv' => 'Maldives',
	'UserCountry_country_mw' => 'Malawi',
	'UserCountry_country_mx' => 'Mexico',
	'UserCountry_country_my' => 'Malaysia',
	'UserCountry_country_mz' => 'Mozambique',
	'UserCountry_country_na' => 'Namibia',
	'UserCountry_country_nc' => 'New Caledonia',
	'UserCountry_country_ne' => 'Niger',
	'UserCountry_country_nf' => 'Norfolk Island',
	'UserCountry_country_ng' => 'Nigeria',
	'UserCountry_country_ni' => 'Nicaragua',
	'UserCountry_country_nl' => 'Netherlands',
	'UserCountry_country_no' => 'Norway',
	'UserCountry_country_np' => 'Nepal',
	'UserCountry_country_nr' => 'Nauru',
	'UserCountry_country_nt' => 'Neutral Zone',
	'UserCountry_country_nu' => 'Niue',
	'UserCountry_country_nz' => 'New Zealand',
	'UserCountry_country_om' => 'Oman',
	'UserCountry_country_pa' => 'Panama',
	'UserCountry_country_pe' => 'Peru',
	'UserCountry_country_pf' => 'French Polynesia',
	'UserCountry_country_pg' => 'Papua New Guinea',
	'UserCountry_country_ph' => 'Philippines',
	'UserCountry_country_pk' => 'Pakistan',
	'UserCountry_country_pl' => 'Poland',
	'UserCountry_country_pm' => 'Saint Pierre and Miquelon',
	'UserCountry_country_pn' => 'Pitcairn',
	'UserCountry_country_pr' => 'Puerto Rico',
	'UserCountry_country_ps' => 'Palestinian Territory',
	'UserCountry_country_pt' => 'Portugal',
	'UserCountry_country_pw' => 'Palau',
	'UserCountry_country_py' => 'Paraguay',
	'UserCountry_country_qa' => 'Qatar',
	'UserCountry_country_re' => 'Reunion Island',
	'UserCountry_country_ro' => 'Romania',
	'UserCountry_country_ru' => 'Russia',
	'UserCountry_country_rs' => 'Serbia',
	'UserCountry_country_rw' => 'Rwanda',
	'UserCountry_country_sa' => 'Saudi Arabia',
	'UserCountry_country_sb' => 'Solomon Islands',
	'UserCountry_country_sc' => 'Seychelles',
	'UserCountry_country_sd' => 'Sudan',
	'UserCountry_country_se' => 'Sweden',
	'UserCountry_country_sf' => 'Finland',
	'UserCountry_country_sg' => 'Singapore',
	'UserCountry_country_sh' => 'Saint Helena',
	'UserCountry_country_si' => 'Slovenia',
	'UserCountry_country_sj' => 'Svalbard',
	'UserCountry_country_sk' => 'Slovakia',
	'UserCountry_country_sl' => 'Sierra Leone',
	'UserCountry_country_sm' => 'San Marino',
	'UserCountry_country_sn' => 'Senegal',
	'UserCountry_country_so' => 'Somalia',
	'UserCountry_country_sr' => 'Suriname',
	'UserCountry_country_st' => 'Sao Tome and Principe',
	'UserCountry_country_su' => 'Old U.S.S.R',
	'UserCountry_country_sv' => 'El Salvador',
	'UserCountry_country_sy' => 'Syrian Arab Republic',
	'UserCountry_country_sz' => 'Swaziland',
	'UserCountry_country_ta' => 'Tristan da Cunha',
	'UserCountry_country_tc' => 'Turks and Caicos Islands',
	'UserCountry_country_td' => 'Chad',
	'UserCountry_country_tf' => 'French Southern Territories',
	'UserCountry_country_tg' => 'Togo',
	'UserCountry_country_th' => 'Thailand',
	'UserCountry_country_tj' => 'Tajikistan',
	'UserCountry_country_tk' => 'Tokelau',
	'UserCountry_country_tl' => 'East Timor',
	'UserCountry_country_tm' => 'Turkmenistan',
	'UserCountry_country_tn' => 'Tunisia',
	'UserCountry_country_to' => 'Tonga',
	'UserCountry_country_tp' => 'East Timor',
	'UserCountry_country_tr' => 'Turkey',
	'UserCountry_country_tt' => 'Trinidad and Tobago',
	'UserCountry_country_tv' => 'Tuvalu',
	'UserCountry_country_tw' => 'Taiwan',
	'UserCountry_country_tz' => 'Tanzania, United Republic of',
	'UserCountry_country_ua' => 'Ukraine',
	'UserCountry_country_ug' => 'Uganda',
	'UserCountry_country_uk' => 'United Kingdom',
	'UserCountry_country_um' => 'United States Minor Outlying Islands',
	'UserCountry_country_us' => 'United States',
	'UserCountry_country_uy' => 'Uruguay',
	'UserCountry_country_uz' => 'Uzbekistan',
	'UserCountry_country_va' => 'Vatican City',
	'UserCountry_country_vc' => 'Saint Vincent and the Grenadines',
	'UserCountry_country_ve' => 'Venezuela',
	'UserCountry_country_vg' => 'Virgin Islands, British',
	'UserCountry_country_vi' => 'Virgin Islands, U.S.',
	'UserCountry_country_vn' => 'Vietnam',
	'UserCountry_country_vu' => 'Vanuatu',
	'UserCountry_country_wf' => 'Wallis and Futuna',
	'UserCountry_country_ws' => 'Samoa',
	'UserCountry_country_ye' => 'Yemen',
	'UserCountry_country_yt' => 'Mayotte',
	'UserCountry_country_yu' => 'Yugoslavia',
	'UserCountry_country_za' => 'South Africa',
	'UserCountry_country_zm' => 'Zambia',
	'UserCountry_country_zr' => 'Zaire',
	'UserCountry_country_zw' => 'Zimbabwe',
	'UserCountry_continent_eur' => 'Europe',
	'UserCountry_continent_afr' => 'Africa',
	'UserCountry_continent_asi' => 'Asia',
	'UserCountry_continent_ams' => 'South and Central America',
	'UserCountry_continent_amn' => 'North America',
	'UserCountry_continent_oce' => 'Oceania',
	'VisitsSummary_VisitsSummary' => 'Visits Summary',
	'VisitsSummary_NbVisits' => '%s visits',
	'VisitsSummary_NbUniqueVisitors' => '%s unique visitors',
	'VisitsSummary_NbActions' => '%s actions (page views)',
	'VisitsSummary_TotalTime' => '%s total time spent by the visitors',
	'VisitsSummary_MaxNbActions' => '%s max actions in one visit',
	'VisitsSummary_NbVisitsBounced' => '%s visits have bounced (left the website after one page)',
	'VisitsSummary_EvolutionOverLastPeriods' => 'Evolution over the last %s',
	'VisitsSummary_Report' => 'Report',
	'VisitsSummary_GenerateTime' => '%s seconds to generate the page',
	'VisitsSummary_GenerateQueries' => '%s queries executed',
	'VisitsSummary_WidgetLastVisits' => 'Last visits graph',
	'VisitsSummary_WidgetVisits' => 'Visits overview',
	'VisitsSummary_WidgetLastVisitors' => 'Last unique visitors graph',
	'VisitsSummary_WidgetOverviewGraph' => 'Overview with graph',
	'VisitsSummary_SubmenuOverview' => 'Overview',
	'VisitFrequency_Evolution' => 'Evolution over the period',
	'VisitFrequency_ColumnReturningVisits' => 'Returning Visits',
	'VisitFrequency_ColumnActionsByReturningVisits' => 'Actions by Returning Visits',
	'VisitFrequency_ColumnMaximumActionsByAReturningVisit' => 'Maximum Actions by a Returning Visit',
	'VisitFrequency_ColumnTotalTimeSpentByReturningVisits' => 'Total time spent by Returning Visits (in seconds)',
	'VisitFrequency_ColumnBounceRateForReturningVisits' => 'Bounce rate for Returning Visits',
	'VisitFrequency_ReturnVisits' => '%s returning visits',
	'VisitFrequency_ReturnActions' => '%s actions by the returning visits',
	'VisitFrequency_ReturnMaxActions' => '%s maximum actions by a returning visit',
	'VisitFrequency_ReturnTotalTime' => '%s total time spent by returning visits',
	'VisitFrequency_ReturnBounceRate' => '%s returning visits have bounced (left the website after one page)',
	'VisitFrequency_WidgetOverview' => 'Frequency overview',
	'VisitFrequency_WidgetGraphReturning' => 'Graph returning visits',
	'VisitFrequency_SubmenuFrequency' => 'Frequency',
	'VisitTime_LocalTime' => 'Visits per local time',
	'VisitTime_ServerTime' => 'Visits per server time',
	'VisitTime_ColumnServerTime' => 'Server time',
	'VisitTime_ColumnLocalTime' => 'Local time',
	'VisitTime_WidgetLocalTime' => 'Visits by local time',
	'VisitTime_WidgetServerTime' => 'Visits by server time',
	'VisitTime_SubmenuTimes' => 'Times',
	'VisitTime_NHour' => '%sh',
	'VisitorInterest_VisitsPerDuration' => 'Visits per visit duration',
	'VisitorInterest_VisitsPerNbOfPages' => 'Visits per number of pages',
	'VisitorInterest_ColumnVisitDuration' => 'Visit duration',
	'VisitorInterest_ColumnPagesPerVisit' => 'Pages per visit',
	'VisitorInterest_WidgetLengths' => 'Length of Visits',
	'VisitorInterest_WidgetPages' => 'Pages per visit',
	'VisitorInterest_SubmenuFrequencyLoyalty' => 'Frequency &amp; Loyalty',
	'VisitorInterest_PlusXMin' => '%s min',
	'VisitorInterest_BetweenXYMinutes' => '%1s-%1s min',
	'VisitorInterest_OnePage' => '1 page',
	'VisitorInterest_NPages' => '%s pages',
	'VisitorInterest_BetweenXYSeconds' => '%1s-%2ss',
	'Login_LoginPasswordNotCorrect' => 'Username & Password not correct',
	'Login_Login' => 'Username',
	'Login_Password' => 'Password',
	'Login_PasswordRepeat' => 'Password (repeat)',
	'Login_ChangePassword' => 'Change password',
	'Login_LoginOrEmail' => 'Login or E-mail',
	'Login_LogIn' => 'Sign in',
	'Login_Logout' => 'Sign out',
	'Login_LostYourPassword' => 'Lost your password?',
	'Login_RemindPassword' => 'Send password reset',
	'Login_PasswordResetToken' => 'Password reset token',
	'Login_PasswordReminder' => 'Please enter your username or e-mail address. You will receive an e-mail with information to reset your password.',
	'Login_PasswordsDoNotMatch' => 'Passwords do not match.',
	'Login_PasswordSuccessfullyChanged' => 'Password successfully changed!',
	'Login_InvalidUsernameEmail' => 'Invalid username and/or e-mail address',
	'Login_InvalidOrExpiredToken' => 'Token is invalid or has expired',
	'Login_MailTopicPasswordRecovery' => 'Password recovery',
	'Login_MailPasswordRecoveryBody' => "Hi %s,\n\nA password reset request was received from %s.\n\nTo reset your password:\n\n1) Go to the Password Reset Form at:\n\t%s\n\n2) Enter the following token:\n\t%s\n\n3) Fill out the form (entering your new password twice) and submit.\n\nNote: this token will expire in 24 hrs.\n",
	'Login_PasswordSent' => 'Information to reset your password has been sent. Check your e-mail.',
	'Login_ContactAdmin' => 'Possible reason: your host may have disabled the mail() function. <br />Please contact your Piwik administrator.',
	'UsersManager_UsersManagement' => 'Users Management',
	'UsersManager_UsersManagementMainDescription' => 'Create new users or update the existing users. You can then set their permissions above.',
	'UsersManager_ManageAccess' => 'Manage access',
	'UsersManager_MainDescription' => 'Decide which users have which Piwik access on your Websites. You can also set the permissions on all the Websites at once.',
	'UsersManager_Sites' => 'Websites',
	'UsersManager_AllWebsites' => 'All websites',
	'UsersManager_ApplyToAllWebsites' => 'Apply to all websites',
	'UsersManager_User' => 'User',
	'UsersManager_PrivNone' => 'No access',
	'UsersManager_PrivView' => 'View',
	'UsersManager_PrivAdmin' => 'Admin',
	'UsersManager_ChangeAllConfirm' => 'Are you sure you want to change \'%s\' permissions on all the websites?',
	'UsersManager_Login' => 'Login',
	'UsersManager_Password' => 'Password',
	'UsersManager_Email' => 'Email',
	'UsersManager_Alias' => 'Alias',
	'UsersManager_Edit' => 'Edit',
	'UsersManager_AddUser' => 'Add a new user',
	'UsersManager_MenuUsers' => 'Users',
	'UsersManager_DeleteConfirm_js' => 'Are you sure you want to delete the user %s?',
	'UsersManager_ExceptionLoginExists' => 'Login \'%s\' already exists.',
	'UsersManager_ExceptionEmailExists' => 'User with email \'%s\' already exists.',
	'UsersManager_ExceptionInvalidLoginFormat' => 'The login must be between %s and %s characters long and contain only letters, numbers, or the characters \'_\' or \'-\' or \'.\'',
	'UsersManager_ExceptionInvalidPassword' => 'The password length must be between 6 and 26 characters.',
	'UsersManager_ExceptionInvalidEmail' => 'The email doesn\'t have a valid format.',
	'UsersManager_ExceptionDeleteDoesNotExist' => 'User \'%s\' doesn\'t exist therefore it can\'t be deleted.',
	'UsersManager_ExceptionAdminAnonymous' => 'You cannot grant \'admin\' access to the \'anonymous\' user.',
	'UsersManager_ExceptionEditAnonymous' => 'The anonymous user cannot be edited or deleted. It is used by Piwik to define a user that has not logged in yet. For example, you can make your statistics public by granting the \'view\' access to the \'anonymous\' user.',
	'UsersManager_ExceptionSuperUser' => 'Requested user is the Super User and cannot be queried, edited or deleted via the API. You can manually edit the Super User details in your Piwik configuration file.',
	'UsersManager_ExceptionUserDoesNotExist' => 'User \'%s\' doesn\'t exist.',
	'UsersManager_ExceptionAccessValues' => 'The parameter access must have one of the following values : [ %s ]',
	'SitesManager_Sites' => 'Websites',
	'SitesManager_WebsitesManagement' => 'Websites Management',
	'SitesManager_MainDescription' => 'Your Web Analytics reports need Websites! Add, update, delete Websites, and show the JavaScript to insert in your pages.',
	'SitesManager_JsTrackingTag' => 'JavaScript Tracking Tag',
	'SitesManager_JsTrackingTagHelp' => 'Here is the JavaScript Tracking tag to include on all your pages',
	'SitesManager_ShowTrackingTag' => 'show tracking tag',
	'SitesManager_NoWebsites' => 'You don\'t have any website to administrate.',
	'SitesManager_AddSite' => 'Add a new website',
	'SitesManager_AliasUrlHelp' => 'It is recommended, but not required, to specify the various URLs that your visitors use to access this website. 
Alias URLs for a website will not appear in the Referers > Websites report. 
Note that it is not necessary to specify the URLs with and without \'www\' as Piwik automatically considers both.',
	'SitesManager_Id' => 'Id',
	'SitesManager_Name' => 'Name',
	'SitesManager_Urls' => 'URLs',
	'SitesManager_MenuSites' => 'Websites',
	'SitesManager_DeleteConfirm_js' => 'Are you sure you want to delete the website %s?',
	'SitesManager_ExceptionDeleteSite' => 'It is not possible to delete this website as it is the only registered website. Add a new website first, then delete this one.',
	'SitesManager_ExceptionNoUrl' => 'You must specify at least one URL for the website.',
	'SitesManager_ExceptionEmptyName' => 'The website name can\'t be empty.',
	'SitesManager_ExceptionInvalidUrl' => 'The url \'%s\' is not a valid URL.',
	'Installation_Installation' => 'Installation',
	'Installation_InstallationStatus' => 'Installation status',
	'Installation_PercentDone' => '%s %% Done',
	'Installation_NoConfigFound' => 'The Piwik configuration file couldn\'t be found and you are trying to access a Piwik page.<br /><b>&nbsp;&nbsp;&raquo; You can <a href=\'index.php\'>install Piwik now</a></b><br /><small>If you installed Piwik before and have some tables in your DB, don\'t worry, you can reuse the same tables and keep your existing data!</small>',
	'Installation_DatabaseSetup' => 'Database setup',
	'Installation_DatabaseSetupServer' => 'database server',
	'Installation_DatabaseSetupLogin' => 'login',
	'Installation_DatabaseSetupPassword' => 'password',
	'Installation_DatabaseSetupDatabaseName' => 'database name',
	'Installation_DatabaseSetupTablePrefix' => 'table prefix',
	'Installation_DatabaseSetupAdapter' => 'adapter',
	'Installation_DatabaseErrorConnect' => 'Error while trying to connect to the database server',
	'Installation_DatabaseCheck' => 'Database check',
	'Installation_DatabaseServerVersion' => 'Database server version',
	'Installation_DatabaseCreation' => 'Database creation',
	'Installation_DatabaseClientCharset' => 'Database client character set',
	'Installation_ConnectionCharacterSetNotUtf8' => 'Client connection to the database server is not set to UTF8 by default. This is not critical issue: <b>Piwik should work correctly</b>. However for consistency, it is recommended that you do one of the following: <ul style="list-style: disc;margin-left:10px"><li>in your piwik config/config.ini.php, add <code>charset = utf8</code> under the [database] section of your Piwik configuration file <code>config/config.ini.php</code></li><li>recompile libmysql --with-charset=utf8</li></ul>',
	'Installation_DatabaseTimezone' => 'Database timezone',
	'Installation_TimezoneMismatch' => 'PHP date.timezone is not the same as the database server timezone. This might cause issues with reports not showing data for the right hours of the day. More information at %s',
	'Installation_JsTag' => 'JavaScript tag',
	'Installation_JsTagHelp' => '<p>To count all visitors, you must insert the JavaScript code on all of your pages.</p><p>Your pages do not have to be made with PHP, Piwik will work on all kinds of pages (whether it is HTML, ASP, Perl or any other languages).</p><p>Here is the code you have to insert: (copy and paste on all your pages) </p>',
	'Installation_JsTagHelpTitle' => 'How to insert the tag in your websites?',
	'Installation_LargePiwikInstances' => 'Help for large Piwik instances',
	'Installation_JsTagArchivingHelp' => 'For medium and high traffic websites, check out the  <a target="_blank" href="http://piwik.org/docs/setup-auto-archiving/">How to setup auto archiving page</a> to make Piwik run really fast!',
	'Installation_Congratulations' => 'Congratulations',
	'Installation_CongratulationsHelp' => '<p>Congratulations! Your Piwik installation is complete.</p><p>Make sure your JavaScript code is entered on your pages, and wait for your first visitors!</p>',
	'Installation_ContinueToPiwik' => 'Continue to Piwik',
	'Installation_SetupWebsite' => 'Setup a website',
	'Installation_SetupWebSiteName' => 'website name',
	'Installation_SetupWebSiteURL' => 'website URL',
	'Installation_SetupWebsiteError' => 'There was an error when adding the website',
	'Installation_SetupWebsiteSetupSuccess' => 	'Website %s created with success!',
	'Installation_GeneralSetup' => 'General Setup',
	'Installation_GeneralSetupSuccess' => 'General Setup configured with success',
	'Installation_SuperUserLogin' => 'super user login',
	'Installation_Password' => 'password',
	'Installation_PasswordRepeat' => 'password (repeat)',
	'Installation_Email' => 'email',
	'Installation_SecurityNewsletter' => 'email me with major Piwik upgrades and security alerts',
	'Installation_CommunityNewsletter' => 'email me with community updates (new plugins, new features, etc.)',
	'Installation_PasswordDoNotMatch' => 'password do not match',
	'Installation_SubmitGo' => 'Go!',
	'Installation_Requirements' => 'Piwik Requirements',
	'Installation_Optional' => 'Optional',
	'Installation_Legend' => 'Legend',
	'Installation_Extension' => 'extension',
	'Installation_SystemCheck' => 'System check',
	'Installation_SystemCheckPhp' => 'PHP version',
	'Installation_SystemCheckExtensions' => 'Other required extensions',
	'Installation_SystemCheckDatabaseHelp' => 'Piwik requires either the mysqli extension or both the PDO and pdo_mysql extensions.',
	'Installation_SystemCheckPdoAndMysqliHelp' => "On a Linux server you can compile php with the following options: %s\nIn your php.ini, add the following lines: %s",
	'Installation_SystemCheckPhpPdoAndMysqliSite' => 'More information on: <a style="color:red" href="http://php.net/pdo">PHP PDO</a> and <a style="color:red" href="http://php.net/mysqli">MYSQLI</a>.',
	'Installation_SystemCheckWinPdoAndMysqliHelp' => 'On a Windows server you can add the following lines to your php.ini: %s',
	'Installation_SystemCheckSplHelp' => 'You need to configure and rebuild PHP with the Standard PHP Library (SPL) enabled (by default).',
	'Installation_SystemCheckZlibHelp' => 'You need to configure and rebuild PHP with "zlib" support enabled, --with-zlib.',
	'Installation_SystemCheckIconvHelp' => 'You need to configure and rebuild PHP with "iconv" support enabled, --with-iconv.',
	'Installation_SystemCheckDomHelp' => 'DOM is part of PHP core. You probably need to install the dom module, e.g., php-5-dom.',
	'Installation_SystemCheckJson' => 'JSON',
	'Installation_SystemCheckJsonHelp' => 'You need to configure and rebuild PHP with either "json" or "xml" extensions enabled.',
	'Installation_SystemCheckJsonSite' => 'More information on: <a style="color:red" href="http://php.net/json">PHP JSON</a>.',
	'Installation_SystemCheckXml' => 'XML',
	'Installation_SystemCheckXmlHelp' => 'Some third-party plugins and developer libraries may require the "xml" extension.',
	'Installation_SystemCheckXmlSite' => 'More information on: <a style="color:red" href="http://php.net/xml">PHP XML</a>.',
	'Installation_SystemCheckWriteDirs' => 'Directories with write access',
	'Installation_SystemCheckWriteDirsHelp' => 'To fix this error on your Linux system, try typing in the following command(s)',
	'Installation_SystemCheckMemoryLimit' => 'Memory limit',
	'Installation_SystemCheckMemoryLimitHelp' => 'On a high traffic website, the archiving process may require more memory than currently allowed.  If necessary, change the memory_limit directive in your php.ini file.',
	'Installation_SystemCheckOpenURL' => 'Open URL',
	'Installation_SystemCheckOpenURLHelp' => 'Newsletter subscriptions, update notifications, and one-click updates requires the "curl" extension, allow_url_fopen=On, or fsockopen() enabled.',
	'Installation_SystemCheckGD' => 'GD &gt; 2.x (graphics)',
	'Installation_SystemCheckGDHelp' => 'The sparklines (small graphs) will not work.',
	'Installation_SystemCheckFunctions' => 'Required functions',
	'Installation_SystemCheckTimeLimitHelp' => 'On a high traffic website, executing the archiving process may require more time than currently allowed.  If necessary, change the max_execution_time directive in your php.ini file.',
	'Installation_SystemCheckMailHelp' => 'Feedback and Lost Password messages will not be sent without mail().',
	'Installation_SystemCheckError' => 'An error occured - must be fixed before you proceed',
	'Installation_SystemCheckWarning' => 'Piwik will work normally but some features may be missing',
	'Installation_SystemCheckProtocol' => 'Protocol',
	'Installation_SystemCheckProtocolHelp' => 'If you are behind a reverse proxy, add these lines to config/config.ini.php under the [General] section:',
	'Installation_Tables' => 'Creating the tables',
	'Installation_TablesWithSameNamesFound' => 'Some %s tables in your database %s have the same names as the tables Piwik is trying to create',
	'Installation_TablesFound' => 'The following tables have been found in the database',
	'Installation_TablesWarningHelp' => 'Either choose to reuse the existing database tables or select a clean install to erase all existing data in the database.',
	'Installation_TablesReuse' => 'Reuse the existing tables',
	'Installation_TablesDelete' => 'Delete the detected tables',
	'Installation_TablesDeletedSuccess' => 'Existing Piwik tables deleted with success',
	'Installation_TablesCreatedSuccess' => 'Tables created with success!',
	'Installation_DatabaseCreatedSuccess' => 'Database %s created with success!',
	'Installation_GoBackAndDefinePrefix' => 'Go back and define a Prefix for the Piwik Tables',
	'Installation_ConfirmDeleteExistingTables' => 'Are you sure you want to delete the tables: %s from your database? WARNING: DATA FROM THESE TABLES CANNOT BE RECOVERED!',
	'Installation_Welcome' => 'Welcome!',
	'Installation_WelcomeHelp' => '<p>Piwik is an open source web analytics software that makes it easy to get the information you want from your visitors.</p><p>This process is split up into %s easy steps and will take around 5 minutes.</p>',
	'Installation_ErrorInvalidState' => 'Error: it seems you try to skip a step of the Installation process, or your cookies are disabled, or the Piwik configuration file is already created. %sMake sure your cookies are enabled%s and go back %s to the first page of the installation %s.',
	'Provider_WidgetProviders' => 'Providers',
	'Provider_ColumnProvider' => 'Provider',
	'Provider_SubmenuLocationsProvider' => 'Locations &amp; Provider',
	'Goals_ColumnConversions' => 'Conversions',
	'Goals_ColumnConversionRate' => 'Conversion Rate',
	'Goals_ColumnRevenue' => 'Revenue',
	'DBStats_DatabaseUsage' => 'Database usage',
	'DBStats_MainDescription' => 'Piwik is storing all your web analytics data in the MySQL database. Currently, Piwik tables are using %s.',
	'DBStats_LearnMore' => 'To learn more about how Piwik processes data and how to make Piwik work well for medium and high traffic websites, check out the documentation %s.',
	'DBStats_Table' => 'Table',
	'DBStats_RowCount' => 'Row count',
	'DBStats_DataSize' => 'Data size',
	'DBStats_IndexSize' => 'Index size',
	'DBStats_TotalSize' => 'Total size',
	'TranslationsAdmin_MenuTranslations' => 'Translations',
	'TranslationsAdmin_MenuLanguages' => 'Languages',
	'TranslationsAdmin_Plugin' => 'Plugin',
	'TranslationsAdmin_Definition' => 'Definition',
	'TranslationsAdmin_DefaultString' => 'Default string (English)',
	'TranslationsAdmin_TranslationString' => 'Translation string (current language: %s)',
	'TranslationsAdmin_Translations' => 'Translations',
	'TranslationsAdmin_FixPermissions' => 'Please fix filesystem permissions',
	'TranslationsAdmin_AvailableLanguages' => 'Available languages',
	'TranslationsAdmin_AddLanguage' => 'Add language',
	'TranslationsAdmin_LanguageCode' => 'Language code',
	'TranslationsAdmin_Export' => 'Export language',
	'TranslationsAdmin_Import' => 'Import language',
	'SecurityInfo_Security' => 'Security',
	'SecurityInfo_SecurityInformation' => 'PHP Security Information',
	'SecurityInfo_PluginDescription' => 'Based on PhpSecInfo from the PHP Security Consortium, this plugin provides security information about your PHP environment and offers suggestions for improvement. It is a tool in a multilayered security approach. It does not replace secure development practices nor audit the code/application.',
	'SecurityInfo_Test' => 'Test',
	'SecurityInfo_Result' => 'Result',
	'Live_VisitorLog' => 'Visitor Log',
	'Live_Date' => 'Date',
	'Live_Time' => 'Time',
	'Live_Referrer_URL' => 'Referrer URL',
);
